Boruta core v1.0.0-rc.0 Boruta.Oauth View Source
Boruta OAuth entrypoint, handles OAuth requests.
Note : this module works in association with Boruta.Oauth.Application behaviour
Link to this section Summary
Functions
Triggers authorize_success in case of success and authorize_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Triggers introspect_success in case of success and introspect_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Triggers token_success in case of success and token_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Link to this section Functions
Specs
authorize( conn :: Plug.Conn.t() | map(), resource_owner :: struct(), module :: atom() ) :: any()
Triggers authorize_success in case of success and authorize_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Specs
introspect(conn :: Plug.Conn.t() | map(), module :: atom()) :: any()
Triggers introspect_success in case of success and introspect_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Specs
revoke(conn :: Plug.Conn.t() | map(), module :: atom()) :: any()
Specs
token(conn :: Plug.Conn.t() | map(), module :: atom()) :: any()
Triggers token_success in case of success and token_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.