View Source Boruta.Openid.Application behaviour (Boruta core v2.1.0)
Implement this behaviour in the application layer of your OpenID Connect provider.
This behaviour gives all callbacks triggered invoking Boruta.Openid module functions.
Note: This behaviour is splitted into
Boruta.Openid.JwksApplicationandBoruta.Openid.UserinfoApplicationproviding utilities to implement the different OpenID Connect endpoints independently.
Link to this section Summary
Callbacks
This function will be triggered in case of success invoking Boruta.Openid.jwks/2
This function will be triggered when request is unauthorized invoking Boruta.Openid.userinfo/2
This function will be triggered in case of success invoking Boruta.Openid.userinfo/2
Link to this section Callbacks
Specs
jwk_list( conn :: Plug.Conn.t(), jwk_keys :: [%JOSE.JWK{fields: term(), keys: term(), kty: term()}] ) :: any()
This function will be triggered in case of success invoking Boruta.Openid.jwks/2
Specs
unauthorized(conn :: Plug.Conn.t(), error :: Boruta.Oauth.Error.t()) :: any()
This function will be triggered when request is unauthorized invoking Boruta.Openid.userinfo/2
Specs
userinfo_fetched(conn :: Plug.Conn.t(), userinfo :: map()) :: any()
This function will be triggered in case of success invoking Boruta.Openid.userinfo/2