Boruta core v0.2.0 Boruta.Oauth View Source
Boruta OAuth entrypoint, handles OAuth requests.
Note : this module works in association with Boruta.Oauth.Application behaviour
Link to this section Summary
Functions
Triggers authorize_success in case of success and authorize_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Triggers introspect_success in case of success and introspect_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Triggers token_success in case of success and token_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Link to this section Functions
authorize(conn, module)
View Sourceauthorize(conn :: Plug.Conn.t() | map(), module :: atom()) :: any()
Triggers authorize_success in case of success and authorize_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
Note : resource owner must be provided as current_user assigns.
introspect(conn, module)
View Sourceintrospect(conn :: Plug.Conn.t() | map(), module :: atom()) :: any()
Triggers introspect_success in case of success and introspect_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.
revoke(conn, module)
View Sourcerevoke(conn :: Plug.Conn.t() | map(), module :: atom()) :: any()
token(conn, module)
View Sourcetoken(conn :: Plug.Conn.t() | map(), module :: atom()) :: any()
Triggers token_success in case of success and token_error in case of failure from the given module. Those functions are described in Boruta.Oauth.Application behaviour.